==> kde4base_3.80.1.orig.tar.gz: kde4base-3.80.1/kate/app/katemain.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef __KATE_MAIN_H__
#define __KATE_MAIN_H__

#include <config.h>
//Added by qt3to4:
#include <QPixmap>
#include <QLabel>
#include <QVBoxLayout>
#include <QGridLayout>
#include <QEvent>

#define KATE_VERSION "2.5"

class QComboBox;
class QDateTime;
class QEvent;
class QFileInfo;
class QGridLayout;
class QLabel;
class QObject;
class QPixmap;
class QVBoxLayout;
class QString;

class KAction;
class KActionMenu;
class KConfig;
class KDirOperator;
class KEditToolbar;
class KFileViewItem;
class KHistoryCombo;
class KLineEdit;
class KListBox;
class KProcess;
class KPushButton;
class KRecentFilesAction;
class KSelectAction;
class KStatusBar;
class KToggleAction;
class KUrl;
class KUrlComboBox;

class KateApp;
class KateConfigDlg;
class KateConsole;
class KateDocManager;
class KateFileList;
class KateFileSelector;
class KateMainWindow;
class KatePluginIface;
class KatePluginManager;
class KateSidebar;
class KateViewManager;
class KateViewSpace;
class KatePartManager;

#endif

==> kde4base_3.80.3.orig.tar.gz: kde4base-3.80.3/kate/app/katemain.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef __KATE_MAIN_H__
#define __KATE_MAIN_H__

/**
 * This header has some global forward declarations for the whole application
 * and includes the config.h
 */

#include <config.h>

#include <QPixmap>
#include <QLabel>
#include <QVBoxLayout>
#include <QGridLayout>
#include <QEvent>

class QComboBox;
class QDateTime;
class QEvent;
class QFileInfo;
class QGridLayout;
class QLabel;
class QObject;
class QPixmap;
class QVBoxLayout;
class QString;

class KAction;
class KActionMenu;
class KConfig;
class KDirOperator;
class KEditToolbar;
class KFileViewItem;
class KHistoryCombo;
class KLineEdit;
class KListWidget;
class KProcess;
class KPushButton;
class KRecentFilesAction;
class KSelectAction;
class KStatusBar;
class KToggleAction;
class KUrl;
class KUrlComboBox;

class KateApp;
class KateConfigDlg;
class KateDocManager;
class KateFileList;
class KateMainWindow;
class KatePluginManager;
class KateViewManager;
class KateViewSpace;

#endif
// kate: space-indent on; indent-width 2; replace-tabs on;
